
# Enum: EmploymentEventType


codes for different kinds of employment/HR related events

URI: [ks:EmploymentEventType](https://w3id.org/linkml/tests/kitchen_sink/EmploymentEventType)


## Other properties

|  |  |  |
| --- | --- | --- |
| **Aliases:** | | HR code |

## Permissible Values

| Text | Description | Meaning | Other Information |
| :--- | :---: | :---: | ---: |
| HIRE | event for a new employee | bizcodes:001 |  |
| FIRE |  | bizcodes:002 | {'annotations': {'biolink:opposite': Annotation(tag='biolink:opposite', value='HIRE', extensions={}, annotations={})}} |
| PROMOTION | promotion event | bizcodes:003 |  |
| TRANSFER | transfer internally | bizcodes:004 |  |

